@@ -12,7 +12,8 @@ var arg = process.argv[2];
 var help = ' compile  :    Compile atom file; '
            + '\n create   :    Create an Atom project; '
            + '\n server   :    Run a server; '
-           + '\n testSsr  :    Test if Server SSR commands is the same as App commands;';
+           + '\n testSsr  :    Test if Server SSR commands is the same as App commands;'
+           + '\n debug    :    Start to debug; ';
 
 
 if (!arg || arg === 'help') {
